@@ -18,4 +18,5 @@ You should have received a copy of the GNU General Public License
 along with pyromod.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.0.4"
\ No newline at end of file
+from .listen import *
+from .utils import PyromodConfig
