@@ -18,4 +18,4 @@ You should have received a copy of the GNU General Public License
 along with pyromod.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from .utils import patch, patchable
\ No newline at end of file
+from .utils import patch, patchable, PyromodConfig
